desklid — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# desklid

Defines the `DeskLid` class.

class `desklid.` `DeskLid`(desk_lid_id, command_list_id, x_offset)

  A desk lid.

  Parameters: | desk_lid_id – The ID of the desk lid. command_list_id – The ID of the command list the desk lid will use. x_offset – The offset (relative to the desk being opened) at which the desk lid should be displayed.

  `deliver_contents`()

    Deliver the contents of the desk to whoever raised the lid.

  `get_command_list_id`(lesson_id)

    Return the ID of the command list used by the desk lid.

    Parameters: | lesson_id – The ID of the current lesson (ignored - desk lids do not follow a timetable).

  `raise_lid`(desk, character)

    Raise the lid of a desk.

    Parameters: | desk (`Desk`) – The desk. character (`Character`) – The character raising the lid.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »